@@ -1,4 +1,4 @@
-//@line 38 "/builds/tinderbox/Tb-Mozilla1.8.0/Linux_2.4.18-14_Depend/mozilla/toolkit/components/console/content/console.js"
+//@line 38 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/console/content/console.js"
 
 var gConsole, gConsoleBundle, gTextBoxEval;
 
@@ -97,6 +97,8 @@ function displayResult()
   if (result)
     gConsole.mCService.logStringMessage(result);
     // or could use appendMessage which doesn't persist
+  var iframe = document.getElementById("Evaluator");
+  iframe.setAttribute("src", "chrome://global/content/blank.html");
 }
 
 // XXX DEBUG
