@@ -1,3 +1,4 @@
+//@line 39 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/viewsource/content/viewSource.js"
 
 const pageLoaderIface = Components.interfaces.nsIWebPageDescriptor;
 const nsISelectionPrivate = Components.interfaces.nsISelectionPrivate;
@@ -30,10 +31,12 @@ function onLoadViewSource()
 {
   viewSource(window.arguments[0]);
   document.commandDispatcher.focusedWindow = content;
+//@line 74 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/viewsource/content/viewSource.js"
 }
 
 function onUnloadViewSource()
 {
+//@line 81 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/toolkit/components/viewsource/content/viewSource.js"
 }
 
 function getBrowser()
@@ -118,7 +121,7 @@ function viewSource(url)
           // This allows the content to be fetched from the cache (if
           // possible) rather than the network...
           //
-          PageLoader.LoadPage(arg, pageLoaderIface.DISPLAY_AS_SOURCE);
+          PageLoader.loadPage(arg, pageLoaderIface.DISPLAY_AS_SOURCE);
           // The content was successfully loaded from the page cookie.
           loadFromURL = false;
         }
@@ -191,13 +194,7 @@ function ViewSourceClose()
   window.close();
 }
 
-function BrowserReload()
-{
-  // Reload will always reload from cache which is probably not what's wanted
-  BrowserReloadSkipCache();
-}
-
-function BrowserReloadSkipCache()
+function ViewSourceReload()
 {
   const webNavigation = getBrowser().webNavigation;
   webNavigation.reload(webNavigation.LOAD_FLAGS_BYPASS_PROXY | webNavigation.LOAD_FLAGS_BYPASS_CACHE);
@@ -540,24 +537,24 @@ function highlightSyntax()
   gPrefs.setBoolPref("view_source.syntax_highlight", highlightSyntax);
 
   var PageLoader = getBrowser().webNavigation.QueryInterface(pageLoaderIface);
-  PageLoader.LoadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
+  PageLoader.loadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
 }
 
 // Fix for bug 136322: this function overrides the function in
-// browser.js to call PageLoader.LoadPage() instead of BrowserReloadWithFlags()
+// browser.js to call PageLoader.loadPage() instead of BrowserReloadWithFlags()
 function BrowserSetForcedCharacterSet(aCharset)
 {
   var docCharset = getBrowser().docShell.QueryInterface(
                             Components.interfaces.nsIDocCharset);
   docCharset.charset = aCharset;
   var PageLoader = getBrowser().webNavigation.QueryInterface(pageLoaderIface);
-  PageLoader.LoadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
+  PageLoader.loadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
 }
 
 // fix for bug #229503
 // we need to define BrowserSetForcedDetector() so that we can
 // change auto-detect options in the "View | Character Encoding" menu.
-// As with BrowserSetForcedCharacterSet(), call PageLoader.LoadPage() 
+// As with BrowserSetForcedCharacterSet(), call PageLoader.loadPage() 
 // instead of BrowserReloadWithFlags()
 function BrowserSetForcedDetector(doReload)
 {
@@ -565,7 +562,7 @@ function BrowserSetForcedDetector(doReload)
   if (doReload)
   {
     var PageLoader = getBrowser().webNavigation.QueryInterface(pageLoaderIface);
-    PageLoader.LoadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
+    PageLoader.loadPage(PageLoader.currentDescriptor, pageLoaderIface.DISPLAY_NORMAL);
   }
 }
 
