@@ -1566,11 +1566,6 @@ function SelectMessage(messageUri)
     gDBView.selectMsgByKey(msgHdr.messageKey);
 }
 
-function ReloadWithAllParts()
-{
-  gDBView.reloadMessageWithAllParts();
-}
-
 function ReloadMessage()
 {
   gDBView.reloadMessage();
